``eradiate.plot``
=================

.. automodule:: eradiate.plot

.. py:currentmodule:: eradiate.plot

Utility functions
-----------------

.. autosummary::
   :toctree: generated/autosummary/

   detect_axes
   get_axes_from_facet_grid
   make_ticks
   remove_xylabels
   remove_xyticks
   set_style
